==> haskell-crypton-conduit-0.2.3-187-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-conduit
version:              0.2.3
visibility:           public
id:                   crypton-conduit-0.2.3-3VruN5Co5ezDgsAnxnukIS
key:                  crypton-conduit-0.2.3-3VruN5Co5ezDgsAnxnukIS
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Sibi Prabakaran <sibi@psibi.in>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/psibi/crypton-conduit
synopsis:             crypton conduit
description:
    Conduit bridge for crypton

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  c49a56dbe1b27768b6f84f43a9f7fa64
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-conduit
hs-libraries:         HScrypton-conduit-0.2.3-3VruN5Co5ezDgsAnxnukIS
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1
    conduit-extra-1.3.8-CgVZWFLveL3JOQpGK40p1j
    crypton-1.0.3-16cGkRi6FF0JFIvaY823Of exceptions-0.10.5
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-conduit/html/crypton-conduit.haddock

haddock-html:         /usr/share/doc/haskell-crypton-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-conduit-0.2.3-207-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-conduit
version:              0.2.3
visibility:           public
id:                   crypton-conduit-0.2.3-8YLUbIP3JnnK1gdazlEpS4
key:                  crypton-conduit-0.2.3-8YLUbIP3JnnK1gdazlEpS4
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Sibi Prabakaran <sibi@psibi.in>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/psibi/crypton-conduit
synopsis:             crypton conduit
description:
    Conduit bridge for crypton

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  fa9872d165ea20d0dd6d64a6bf1a8d05
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-conduit
hs-libraries:         HScrypton-conduit-0.2.3-8YLUbIP3JnnK1gdazlEpS4
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3
    conduit-extra-1.3.8-1hrV1nPRDhE45dAx9zvo6P
    crypton-1.0.4-AGWvxb3uQebCjfbnRIxIRG exceptions-0.10.5
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-conduit/html/crypton-conduit.haddock

haddock-html:         /usr/share/doc/haskell-crypton-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
